==> foundation-utils-2.0.11.tgz: package/src/loadScript.ts <==
const callbacks = {}

/**
 * 动态加载一个远程脚本
 * @param {String} url 脚本url
 * @param {Function}callback 回调
 * @returns
 */
function LoadScript(url: string, callback: Function) {
  if (!url) return;
  const existingScript = document.getElementById(url)
  const cb = callback || (() => { })
  if (!existingScript) {
    callbacks[url] = []
    const $script = document.createElement('script')
    $script.src = url
    $script.id = url
    $script.async = true
    document.body.appendChild($script)
    const onEnd = 'onload' in $script ? stdOnEnd.bind($script) : ieOnEnd.bind($script)
    onEnd($script)
  }

  callbacks[url].push(cb)

  function stdOnEnd(script) {
    script.onload = () => {
      this.onerror = this.onload = null
      callbacks[url].forEach(item => {
        item(null, script)
      })
      delete callbacks[url]
    }
    script.onerror = () => {
      this.onerror = this.onload = null
      cb(new Error(`Failed to load ${url}`), script)
    }
  }

  function ieOnEnd(script) {
    script.onreadystatechange = () => {
      if (this.readyState !== 'complete' && this.readyState !== 'loaded') return
      this.onreadystatechange = null
      callbacks[url].forEach(item => {
        item(null, script)
      })
      delete callbacks[url]
    }
  }
}

/**
 * 顺序加载一组远程脚本
 * @param {Array} urls 一组远程脚本
 * @param {Function} cb 回调
 */
function LoadScriptQueue(urls: string[], cb: Function) {
  const first = urls.shift()!;
  urls.length ? LoadScript(first, () => LoadScriptQueue(urls, cb)) : LoadScript(first, cb)
}

export {
  LoadScript,
  LoadScriptQueue,
}

/**
 * readme:
 *  使用：
 *    import loadScript from "../loadScript";
 *    loadScript(url);
 *
 */

==> foundation-utils-2.0.19.tgz: package/src/loadScript.ts <==
const callbacks = {}

/**
 * 动态加载一个远程脚本
 * @param {String} url 脚本url
 * @param {Function}callback 回调
 * @returns
 */
function LoadScript(url: string, callback: Function) {
  if (!url) return;
  const existingScript = document.getElementById(url)
  const cb = callback || (() => { })
  if (!existingScript) {
    callbacks[url] = []
    const $script = document.createElement('script')
    $script.src = url
    $script.id = url
    $script.async = true
    document.body.appendChild($script)
    const onEnd = 'onload' in $script ? stdOnEnd.bind($script) : ieOnEnd.bind($script)
    onEnd($script)
  }

  callbacks[url].push(cb)

  function stdOnEnd(script: any) {
    script.onload = () => {
      this.onerror = this.onload = null
      callbacks[url].forEach(item => {
        item(null, script)
      })
      delete callbacks[url]
    }
    script.onerror = () => {
      this.onerror = this.onload = null
      cb(new Error(`Failed to load ${url}`), script)
    }
  }

  function ieOnEnd(script: any) {
    script.onreadystatechange = () => {
      if (this.readyState !== 'complete' && this.readyState !== 'loaded') return
      this.onreadystatechange = null
      callbacks[url].forEach(item => {
        item(null, script)
      })
      delete callbacks[url]
    }
  }
}

/**
 * 顺序加载一组远程脚本
 * @param {Array} urls 一组远程脚本
 * @param {Function} cb 回调
 */
function LoadScriptQueue(urls: string[], cb: Function) {
  const first = urls.shift()!;
  urls.length ? LoadScript(first, () => LoadScriptQueue(urls, cb)) : LoadScript(first, cb)
}

export {
  LoadScript,
  LoadScriptQueue,
}

/**
 * readme:
 *  使用：
 *    import loadScript from "../loadScript";
 *    loadScript(url);
 *
 */
